Class: Identizer::Handlers::Base

Inherits:
Object
  • Object
show all
Includes:
Responses
Defined in:
lib/identizer/handlers/base.rb

Overview

Shared base for the protocol handlers. Each handler is constructed with a context carrying the configuration, identity store, token minter and the in-memory session map (opaque code/token -> Identity).

Instance Method Summary collapse

Methods included from Responses

#amz_json, #escape_html, #html, #json, #no_content, #not_found, #notice_page, #redirect, #xml

Constructor Details

#initialize(context) ⇒ Base

Returns a new instance of Base.



11
12
13
14
15
16
17
18
19
20
# File 'lib/identizer/handlers/base.rb', line 11

def initialize(context)
  @context = context
  @config = context.config
  @store = context.store
  @minter = context.minter
  @codes = context.codes
  @refresh_tokens = context.refresh_tokens
  @access_tokens = context.access_tokens
  @renderer = context.renderer
end